# Copyright (C) 2017 GRNET S.A.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import subprocess
from optparse import make_option

from astakos.im.models import *
from astakos.im import transaction
from snf_django.management.commands import SynnefoCommand


class Command(SynnefoCommand):
    help = "Create users in bulk"
    command_option_list = (
        make_option('--email', default=None),
        make_option('--name', default=None),
        make_option('--surname', default=None),
        make_option('--count-from', default=1),
        make_option('--count-to', default=0),
        make_option('--count', default=1),
        make_option('--group', default=None),
        make_option('--create', action='store_true', default=False),
        make_option('--verify-and-accept', action='store_true', default=False),
        make_option('--nodry', action='store_true', default=False),
    )

    @transaction.atomic
    def handle(self, *args, **options):
        uuids = []

        dry = not options.get('nodry')
        email = options.get('email')
        group = options.get('group')
        count_from = int(options.get('count_from'))
        count = int(options.get('count'))
        count_to = int(options.get('count_to')) or (count_from + count)

        assert email and count_from and count_to and count_to >= count_from
        name = options.get('name') or email.split("@")[0]
        surname = options.get('surname') or email.split("@")[1]
        user_exists = lambda x: AstakosUser.objects.filter(email=x).exists()

        create_command = "snf-manage user-add {email} \"{name}\" \"{surname}\""
        if options.get('create'):
            for i in range(count_from, count_to + 1):
                _email = email.format(i)
                _name = name.format(i)
                _surname = surname.format(i)

                if user_exists(_email):
                    self.stdout.write("User {} already exists".format(_email))
                else:
                    _create_command = create_command.format(email=_email,
                                      name=_name, surname=_surname)
                    self.stdout.write("Running " + _create_command)
                    if not dry:
                        out = subprocess.call(_create_command, shell=True)
                        assert out == 0
                        self.stdout.write("\n")
                self.stdout.write("\n")

        verify_command = "snf-manage user-modify {} --verify --accept"
        if group:
            verify_command += " --add-group={}".format(group)
        if options.get('verify_and_accept'):
            for i in range(count_from, count_to + 1):
                _email = email.format(i)
                if not user_exists(_email):
                    self.stdout.write("Skipping user verification. User does not exist {}".format(_email))
                    self.stdout.write("\n")
                    continue
                user = AstakosUser.objects.get(email=_email).uuid
                _verify_command = verify_command.format(user)
                self.stdout.write("Running {}".format(_verify_command))
                if not dry:
                    out = subprocess.call(_verify_command, shell=True)
                    assert out == 0
                    self.stdout.write("\n")
                self.stdout.write("\n")
