# Copyright (C) 2016 GRNET S.A.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import sys
from optparse import make_option

from django.template import Context, Template
from astakos.im.models import AstakosUser
from astakos.im.user_utils import send_plain as send_email
from synnefo_branding.utils import get_branding_dict
from astakos.im import settings as astakos_settings
from snf_django.management.commands import SynnefoCommand, CommandError


SENDER = astakos_settings.SERVER_EMAIL

class Command(SynnefoCommand):
    help = "Send an email to a list of users"
    args = "<uuids.txt> <subject.txt> <body.txt>"
    command_option_list = (
        make_option('--debug',
                    action="store_true",
                    default=False,
                    help="Run in debug mode"),
        make_option('--nodry',
                    action="store_true",
                    default=False,
                    help="Actually send the emails (no dry run)"),
    )

    def writeline(self, line):
        self.stdout.write(line + "\n")

    def handle(self, *args, **options):
        DRY = not options.get('nodry')
        DEBUG = options.get('debug')
        if len(args) < 3:
            raise CommandError("Missing arguments %s" % self.args)

        users_list = map(lambda x:x.strip(), open(args[0]).readlines())
        subject_content = open(args[1]).read().strip()
        body_content = open(args[2]).read().strip()

        users = AstakosUser.objects.filter(uuid__in=users_list, is_active=True)

        if len(users) != len(users_list):
            self.stdout.write(
                "Users count mismatch file:%d db:%d\n"
                % (len(users), len(users_list)))
            sys.exit(0)

        subject_tpl = Template(subject_content)
        body_tpl = Template(body_content)
        branding = get_branding_dict("")

        for user in users:
            context = Context({'user': user, 'branding': branding})
            subject = subject_tpl.render(context)
            body = body_tpl.render(context)
            if DEBUG:
                self.writeline("%s -> %s email with subject %r" % (SENDER, user.email, subject))
                self.writeline(body)

            if not DRY:
                self.writeline("Sending email to %r, %s" % (user.email, user.uuid))
                send_email(user, sender=SENDER, subject=subject, template_name=None, text=body)
            self.writeline("Email sent to %r, %s" % (user.email, user.uuid))
            if DEBUG:
                self.writeline("--")
