# Copyright (C) 2016-2017 GRNET S.A.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from astakos.im.models import *
from astakos.im import transaction
from snf_django.management.commands import SynnefoCommand


class Command(SynnefoCommand):
    help = """
    Enable local login method and set usable password for the specified user.
    """
    args = "<user uuid>"

    @transaction.atomic
    def handle(self, *args, **options):
        if not len(args):
            self.stdout.write("User uuid is required\n")
            exit(0)

        uuid = args[0]
        user = AstakosUser.objects.select_for_update().get(uuid=uuid)
        try:
            local = user.auth_providers.get(module="local")
            self.stdout.write("Local provider already exists.\n")
            if not local.active:
                self.stdout.write(
                    "Will set disabled local provider to active.\n")
                local.active = True
                local.save()
        except AstakosUserAuthProvider.DoesNotExist:
            user.add_auth_provider("local", None, auth_backend="astakos")
            self.stdout.write("Local provider created.\n")

        if not user.has_usable_password():
            password = AstakosUser.objects.make_random_password()
            user.set_password(password)
            user.save()
            self.stdout.write("User password updated %r. \n" % password)
