# Copyright (C) 2016-2017 GRNET S.A.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from snf_django.management.commands import SynnefoCommand, CommandError
from synnefo.db import transaction
from synnefo.management.common import get_resource


class Command(SynnefoCommand):
    help = """
Set server to owner's system project; assign volumes to server owner
and project"""
    args = "<serverid>"

    @transaction.atomic
    def fix_server_and_volumes(self, serverid):
        server = get_resource("server", serverid, for_update=True)

        new_owner = server.userid
        old_project = server.project
        server.project = new_owner
        server.save()
        msg = "Changed the project of server '%s' from '%s' to '%s'.\n"
        self.stdout.write(msg % (server, old_project, new_owner))
        for vol in server.volumes.all():
            old_owner = vol.userid
            vol.userid = new_owner
            vol_old_project = vol.project
            vol.project = new_owner
            vol.save()
            msg = "Changed the owner of volume '%s' from '%s' to '%s'.\n"
            self.stdout.write(msg % (vol, old_owner, new_owner))
            msg = "Changed the project of volume '%s' from '%s' to '%s'.\n"
            self.stdout.write(msg % (vol, vol_old_project, new_owner))
        self.stdout.write("WARNING: User quotas should be out of sync now,"
                          " run `snf-manage reconcile-resources-cyclades'"
                          " to review and update them.\n")

    def handle(self, *args, **options):
        if len(args) != 1:
            raise CommandError("Please provide a server ID")

        self.fix_server_and_volumes(args[0])
