# Copyright (C) 2017 GRNET S.A.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from snf_django.management.commands import SynnefoCommand, CommandError
from synnefo.db import transaction
from synnefo.management.common import get_resource


class Command(SynnefoCommand):
    help = """Change owner of subnets to match the owner of their network."""
    args = "<networkid> <old_ownerid>"

    @transaction.atomic
    def fix_subnets(self, networkid, old_owner):
        network = get_resource("network", networkid, for_update=True)
        new_owner = network.userid
        subnets = network.subnets.filter(userid=old_owner).select_for_update()
        if not subnets:
            self.stdout.write("No subnets found.\n")
            return
        for subnet in subnets:
            subnet.userid = new_owner
            subnet.save()
            self.stdout.write(
                "Changed the owner of subnet '%s' from '%s' to '%s'.\n" %
                (subnet.id, old_owner, new_owner))

    def handle(self, *args, **options):
        if len(args) != 2:
            raise CommandError("Please provide <networkid> and <old_ownerid>")

        self.fix_subnets(args[0], args[1])
