# Copyright (C) 2016-2017 GRNET S.A.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from optparse import make_option

from astakos.im.models import *
from astakos.im import transaction
from snf_django.management.commands import SynnefoCommand


class Command(SynnefoCommand):
    help = """
    Remove shibboleth login method for the specified user.
    """
    args = "<user uuid>"

    command_option_list = (
        make_option('--nodry', action="store_true", default=False),
    )

    @transaction.atomic
    def handle(self, *args, **options):
        if not len(args):
            self.stdout.write("User uuid is required\n")
            exit(0)

        uuid = args[0]
        user = AstakosUser.objects.select_for_update().get(uuid=uuid)
        shibboleth = user.auth_providers.get(module="shibboleth")
        local = user.auth_providers.get(module="local")
        self.stdout.write("Shibboleth account found %r\n" % shibboleth)
        self.stdout.write("%r\n" % shibboleth.info_data)
        self.stdout.write("\n\n")
        if options.get('nodry'):
            self.stdout.write("Deleting shibboleth provider %r" % shibboleth)
            shibboleth.delete()
            self.stdout.write("Shibboleth provider deleted.")
