# Copyright (C) 2016-2017 GRNET S.A.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from optparse import make_option

from astakos.im.models import *
from astakos.im import transaction
from snf_django.management.commands import SynnefoCommand


class Command(SynnefoCommand):
    help = """
    List shibboleth users with specific filtering criteria.
    """
    option_list = SynnefoCommand.option_list + (
        make_option('--filter', action="append", default=[]),
        make_option('--verbose', action="store_true", default=False),
    )

    @transaction.atomic
    def handle(self, *args, **options):
        insts = options.get('filter')
        verbose = options.get('verbose')
        if not insts:
            return

        qs = AstakosUserAuthProvider.objects.filter()
        q = models.Q()
        for inst in insts:
            q = q | models.Q(module="shibboleth", identifier__contains=inst)
        qs = qs.filter(q)

        for inst in insts:
            q = q | models.Q(user__email__contains=inst)
        qs = qs.filter(q)

        if not verbose:
            self.stdout.write("%d users found\n" % qs.count())
            return

        for user in qs:
            line = "{:50} {:40} {:20}".format(user.identifier, user.user.email,
                                              user.user.status_display)
            self.stdout.write(line + "\n")
