# Copyright (C) 2016-2017 GRNET S.A.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from optparse import make_option

from astakos.im.models import *
from astakos.im import transaction
from snf_django.management.commands import SynnefoCommand


class Command(SynnefoCommand):
    help = """
    List shibboleth users with specific filtering criteria.
    """
    option_list = SynnefoCommand.option_list + (
        make_option('--filter', action="append", default=[]),
    )

    @transaction.atomic
    def handle(self, *args, **options):
        users = AstakosUserAuthProvider.objects.\
            filter(module="shibboleth").select_related("user")

        for filter in options.get('filter'):
            users = users.filter(identifier__contains=filter)

        def write(line):
            self.stdout.write(line + "\n")

        for user in users:
            line = '{:30} {:7} {:50} {:50}'.format(user.identifier,
                                                   str(user.user.is_active),
                                                   str(user.last_login_at),
                                                   str(user.user.last_login))
            write(line)
