# Copyright (C) 2016-2017 GRNET S.A.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from snf_django.management.commands import SynnefoCommand, CommandError
from astakos.im import transaction
from astakos.im import functions, models
from optparse import make_option


class Command(SynnefoCommand):
    help = """Unsuspend a project membership"""
    args = "<project uuid> <user uuid>"

    command_option_list = (
        make_option("--run",
                    help='Execute the actual operations',
                    default=False,
                    action='store_true'),
        )

    @transaction.atomic
    def unsuspend_membership(self, project_id, user_id, run=False):
        membership = models.ProjectMembership.objects.get(
            project__uuid=project_id, person__uuid=user_id)
        self.stdout.write(
            "Membership id: %s, status: %s, project: %s, user: %s\n" % (
                membership.id, membership.state_display(),
                membership.project, membership.person))
        if run:
            functions.unsuspend_membership(membership.id)

    def handle(self, *args, **options):
        if len(args) != 2:
            raise CommandError("Please provide project and user UUID")
        RUN = options.get('run')
        if not RUN:
            self.stdout.write("DRY RUN\n")

        self.unsuspend_membership(args[0], args[1], RUN)
