# Copyright (C) 2016 GRNET S.A.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import itertools
from collections import OrderedDict
import sys
from django.conf import settings
from astakos.im import models


MODULE = sys.modules[__name__]


SOFT_USER_DAYS = getattr(
    settings, 'OVERQUOTA_SOFT_USER_DAYS', [0, 8, 14])
SOFT_ADMIN_DAYS = getattr(
    settings, 'OVERQUOTA_SOFT_ADMIN_DAYS', [15])
HARD_USER_DAYS = getattr(
    settings, 'OVERQUOTA_HARD_USER_DAYS', [16, 23, 30])
HARD_ADMIN_DAYS = getattr(
    settings, 'OVERQUOTA_HARD_ADMIN_DAYS', [31])


SOFT_USER_ACTIONS = getattr(
    settings, 'OVERQUOTA_SOFT_USER_ACTIONS', ['inform_user'])
SOFT_ADMIN_ACTIONS = getattr(
    settings, 'OVERQUOTA_SOFT_ADMIN_ACTIONS', ['inform_admin'])
HARD_USER_ACTIONS = getattr(
    settings, 'OVERQUOTA_HARD_USER_ACTIONS', ['inform_user'])
HARD_ADMIN_ACTIONS = getattr(
    settings, 'OVERQUOTA_HARD_ADMIN_ACTIONS', ['inform_admin'])

EXCLUDE_USERS = getattr(
    settings, 'OVERQUOTA_EXCLUDE_USERS', [])
EXCLUDE_PROJECTS = getattr(
    settings, 'OVERQUOTA_EXCLUDE_PROJECTS', [])

# State when a user is not overquota.
OVERQUOTA_OK = models.ProjectMembership.OVERQUOTA_OK

# State when a user is overquota and it's needed to inform them.
OVERQUOTA_OVERQUOTA = 'OVERQUOTA'

# Default state is OVERQUOTA_OK.
DEFAULT_OVERQUOTA_STATE = OVERQUOTA_OK

# Services which are watched for quota policies.
SERVICES = ['cyclades']

SOFT = 'SOFT'
HARD = 'HARD'

SEVERITY = (SOFT, HARD)

RECIPIENT = ('USER', 'ADMIN')


POLICY_CHAIN = OrderedDict([
    (OVERQUOTA_OK, {
        'policy': tuple(),
        'actions': [],
        }
     ),
    (OVERQUOTA_OVERQUOTA, {
        'policy': tuple(),
        'actions': []
        }
     )
    ])


def construct_policy_chain():
    for severity, recipient in itertools.product(SEVERITY, RECIPIENT):
        state_category = severity + '_' + recipient
        POLICY_CHAIN.update({state_category: {
            'policy': getattr(MODULE, state_category + '_' + 'DAYS'),
            'actions': getattr(MODULE, state_category + '_' + 'ACTIONS')}})


construct_policy_chain()


AMBIGUOUS_TRANSITION = 'SOFT_ADMIN'


SEP = ':'


OVERQUOTA_STATES = [state +
                    (SEP + str(i + 1) if info['policy'] else '')
                    for state, info in POLICY_CHAIN.iteritems()
                    for i in range(len(info['policy']) or 1)]

AVAILABLE_STATES = [OVERQUOTA_OK] + OVERQUOTA_STATES


RESOURCE_ACTIONS = {
    (SOFT, 'cyclades.floating_ip'): ('DETACH', 'cyclades.floating_ip'),
    (HARD, 'cyclades.floating_ip'): ('DESTROY', 'cyclades.floating_ip'),
    (SOFT, 'cyclades.cpu'): ('SHUTDOWN', 'cyclades.vm'),
    (SOFT, 'cyclades.ram'): ('SHUTDOWN', 'cyclades.vm'),
    (SOFT, 'cyclades.vm'): ('SHUTDOWN', 'cyclades.vm'),
    (HARD, 'cyclades.vm'): ('DESTROY', 'cyclades.vm'),
    (HARD, 'cyclades.disk'): ('DESTROY', 'cyclades.disk'),
}

HARD_RESOURCES = ['cyclades.floating_ip', 'cyclades.vm', 'cyclades.disk']

RESOURCES = HARD_RESOURCES + ['cyclades.cpu', 'cyclades.ram']

# List of resources that do not support soft enforcement.
ONLY_HARD_RESOURCES = ['cyclades.disk']
