# Copyright (C) 2016 GRNET S.A.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


# Group that contains the users exempted from expiration check

from collections import OrderedDict
from django.conf import settings

SHIBBOLETH_EXCEPTIONS_GRP = "shibboleth_exception"

NOTIFICATION_SUBJ = 'Verification of your academic login is required'
LNOTICE_SUBJ_PREFIX = '*FINAL NOTICE*'
SUSPEND_TEMPLATE = 'shibboleth/suspend_mail.txt'
WARN_TEMPLATE = 'shibboleth/warning_mail.txt'

SHIB_INFO_ACTION_NAME = 'Last_expire_action'
SHIB_INFO_DATE_NAME = 'Last_expire_action_date'
SHIB_INFO_EXPIRATION_DATE = 'Expiration_date'

""" Do not ignore users using at least one of the RESOURCES """
RESOURCES = [
    "pithos.diskspace",
    "cyclades.disk",
    "cyclades.vm",
    "cyclades.floating_ip",
]

SHIBBOLETH_EXPIRES_DAYS = getattr(settings, 'SHIBBOLETH_EXPIRES_DAYS', 60)

SHIBBOLETH_NOTICE_DAYS = getattr(
    settings, 'SHIBBOLETH_NOTICE_DAYS', [0, 5, 8])
SHIBBOLETH_NOTICE_ACTIONS = getattr(
    settings, 'SHIBBOLETH_NOTICE_ACTIONS', ['send_notice'])
SHIBBOLETH_SUSPEND_DAYS = getattr(
    settings, 'SHIBBOLETH_SUSPEND_DAYS', [15])
SHIBBOLETH_SUSPEND_ACTIONS = getattr(
    settings, 'SHIBBOLETH_SUSPEND_ACTIONS', ['suspend'])
SHIBBOLETH_SUSPEND_UNDO_ACTIONS = getattr(
    settings, 'SHIBBOLETH_SUSPEND_UNDO_ACTIONS', ['unsuspend'])

# Categories
SHIBBOLETH_EXPIRED = 'SHIBBOLETH_EXPIRED'
SHIBBOLETH_NOTICE = 'SHIBBOLETH_NOTICE'
SHIBBOLETH_SUSPEND = 'SHIBBOLETH_SUSPEND'

# the 'delete' state will migrate here
SHIBBOLETH_DELETED = 'SHIBBOLETH_DELETED'

FNOTICE = 'fnotice'  # deprecated
SNOTICE = 'snotice'  # deprecated
LNOTICE = 'lnotice'  # deprecated
SHUTDOWN = 'shutdown'  # deprecated
DELETE = 'delete'  # deprecated

POLICY_CHAIN = OrderedDict([
        (SHIBBOLETH_EXPIRED, {
                'next': SHIBBOLETH_NOTICE,
                'policy': None,
                'actions': [],
        }),
        (SHIBBOLETH_NOTICE, {
                'next': SHIBBOLETH_SUSPEND,
                'policy': SHIBBOLETH_NOTICE_DAYS,
                'actions': SHIBBOLETH_NOTICE_ACTIONS,
                }),
        (SHIBBOLETH_SUSPEND, {
                'next': None,
                'policy': SHIBBOLETH_SUSPEND_DAYS,
                'actions': SHIBBOLETH_SUSPEND_ACTIONS,
                'undo_actions': SHIBBOLETH_SUSPEND_UNDO_ACTIONS,
                }),
        (SHIBBOLETH_DELETED, {
                'next': None,
                'policy': None,
                'actions': [],
                'deprecated': True,
                }),
        ])


SEP = ':'
